<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>AboutDialog</name>
    <message>
        <location filename="../src/core/ui/about.cpp" line="41"/>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="42"/>
        <source>Thanks</source>
        <translation>Agradecimentos</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="43"/>
        <source>Help us</source>
        <translation>Ajude-nos</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="100"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>é uma aplicação multi-plataforma para criar capturas de ecrã do seu ambiente de trabalho.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="102"/>
        <source>It is a light and powerful application, written in Qt.</source>
        <translation>Uma aplicação simples mas poderosa, desenvolvida em Qt.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="34"/>
        <source>using Qt %1</source>
        <translation>usando Qt %1</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="105"/>
        <source>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</source>
        <translation>Website - &lt;a href=&quot;%1&quot;&gt;%1&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="108"/>
        <source>Licensed under the &lt;a href=%1&gt;GPL v2&lt;/a&gt;</source>
        <translation>Licenciado sob a &lt;a href=%1&gt;GPL v2&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="112"/>
        <source>Copyright &amp;copy; 2009-2013, Artem &apos;DOOMer&apos; Galichkin</source>
        <translation>Copyright &amp;copy; 2009-2019, Artem &apos;DOOMer&apos; Galichkin</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="119"/>
        <source>You can join us and help us if you want. This is an invitation if you like this application.</source>
        <translation>Pode ajudar-nos a melhorar a aplicação. Este é um convito casp goste da aplicação.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="122"/>
        <source>What you can do?</source>
        <translation>O que pretende fazer?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="125"/>
        <source>Translate ScreenGrab to other languages</source>
        <translation>Trduza a aplicação para outros idiomas</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="126"/>
        <source>Make suggestions for next releases</source>
        <translation>Efetuar sugestões para as novas versões</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="127"/>
        <source>Report bugs and issues</source>
        <translation>Reportar erros ou melhorias</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="130"/>
        <source>Bug tracker</source>
        <translation>Acompanhamento de erros</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="140"/>
        <source>Translate:</source>
        <translation>Tradução:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="142"/>
        <source> Brazilian Portuguese translation</source>
        <translation> Tradução em português do Brasil</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="143"/>
        <source>Marcio Moraes</source>
        <translation>Marcio Moraes</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="145"/>
        <source> Ukrainian translation</source>
        <translation> Tradução em ucraniano</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="146"/>
        <source>Gennadi Motsyo</source>
        <translation>Gennadi Motsyo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="148"/>
        <source> Spanish translation</source>
        <translation> Tradução em espanhol</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="149"/>
        <source>Burjans L García D</source>
        <translation>Burjans L García D</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="151"/>
        <source> Italian translation</source>
        <translation> Tradução em italiano</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="155"/>
        <source>Testing:</source>
        <translation>Testes:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="157"/>
        <source>Dual monitor support and other in Linux</source>
        <translation>Suporte a duplo monitor e outros em Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="158"/>
        <source>Dual monitor support in Linux</source>
        <translation>Suporte a duplo monitor em Linux</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="159"/>
        <source>win32-build [Windows XP and 7]</source>
        <translation>Versão win32 [Windows XP e 7]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="160"/>
        <source>old win32-build [Windows Vista]</source>
        <translation>Versão win32 antiga [Windows Vista]</translation>
    </message>
    <message>
        <location filename="../src/core/ui/about.cpp" line="161"/>
        <source>win32-build [Windows 7]</source>
        <translation>Versão win32 [Windows 7]</translation>
    </message>
</context>
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="182"/>
        <source>Directory %1 does not exist. Do you want to create it?</source>
        <translation>%1 não existe. Deseja criar o diretório?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="183"/>
        <location filename="../src/core/ui/configwidget.cpp" line="271"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="259"/>
        <source>Select directory</source>
        <translation>Selecionar diretório</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="270"/>
        <source>Do you want to reset the settings to the defaults?</source>
        <translation>Tem a certeza de que deseja repor as definições padrão?</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="314"/>
        <source>Example: </source>
        <translation>Exemplo: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="355"/>
        <source>This key is already used in ScreenGrab! Please select another.</source>
        <translation>Esta tecla já está a ser utilizada or ScreenGrab. Por favor escolha outra.</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="373"/>
        <source>This key is not supported on your system!</source>
        <translation>O seu sistema não tem suporte a esta tecla!</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.cpp" line="393"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
</context>
<context>
    <name>Core</name>
    <message>
        <location filename="../src/core/core.cpp" line="64"/>
        <source>is a crossplatform application for fast creating screenshots of your desktop.</source>
        <translation>é uma aplicação multi-plataforma para criar capturas de ecrã do seu ambiente de trabalho.</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="68"/>
        <source>Take a fullscreen screenshot</source>
        <translation>Obter captura de todo o ecrã</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="72"/>
        <source>Take a screenshot of the active window</source>
        <translation>Obter captura da janela ativa</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="76"/>
        <source>Take a screenshot of a selection of the screen</source>
        <translation>Obter captura de uma área do ecrã</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="80"/>
        <source>Run the application with a hidden main window</source>
        <translation>Executar aplicação com a janea principal ocultada</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="450"/>
        <source>Saved</source>
        <translation>Guardada</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="450"/>
        <source>Saved to </source>
        <translation>Guardada em </translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="472"/>
        <source>Name of saved file is copied to the clipboard</source>
        <translation>Nome do ficheiro é copiado para a área de transferência</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="478"/>
        <source>Path to saved file is copied to the clipboard</source>
        <translation>Caminho do ficheiro é copiado para a área de transferência</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="501"/>
        <source>Copied</source>
        <translation>Copiada</translation>
    </message>
    <message>
        <location filename="../src/core/core.cpp" line="501"/>
        <source>Screenshot is copied to clipboard</source>
        <translation>Captura de ecrã copiada para a área de transferência</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="14"/>
        <source>ScreenGrab</source>
        <translation>ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="79"/>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="89"/>
        <source>Type of screenshot</source>
        <translation>Tipo de captura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="96"/>
        <source>Full screen</source>
        <translation>Ecrã</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="101"/>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="106"/>
        <source>Screen area</source>
        <translation>Área do ecrã</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="111"/>
        <source>Last selected area</source>
        <translation>Última área selecionada</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="141"/>
        <source>Delay:</source>
        <translation>Atraso:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="154"/>
        <source>Delay in seconds before taking screenshot</source>
        <translation>Atraso, em segundos, antes de obter a captura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="157"/>
        <source>None</source>
        <translation>Nada</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="160"/>
        <source> sec</source>
        <translation> seg</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="203"/>
        <source>Zoom area around mouse</source>
        <translation>Ampliar área em redor do rato</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="210"/>
        <source>No window decoration</source>
        <translation>Sem decoração de janelas</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="217"/>
        <source>Include mouse pointer</source>
        <translation>Incluir pointeiro do rato</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.ui" line="246"/>
        <source>toolBar</source>
        <translation>Barra de ferramentas</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="45"/>
        <source>New</source>
        <translation>Nova</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="46"/>
        <source>Save</source>
        <translation>Guardar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="47"/>
        <source>Copy</source>
        <translation>Copiar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="48"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="49"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="73"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="50"/>
        <source>About</source>
        <translation>Acerca</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="51"/>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="315"/>
        <source>Screenshot </source>
        <translation>Captura </translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="319"/>
        <source>Double click to open screenshot in external default image viewer</source>
        <translation>Duplo clique para abrir a captura no visualizador de imagens externo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="328"/>
        <location filename="../src/core/ui/mainwindow.cpp" line="459"/>
        <source>Hide</source>
        <translation>Ocultar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="466"/>
        <source>Show</source>
        <translation>Mostrar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="519"/>
        <source>%1 Files</source>
        <translation>Ficheiros %1</translation>
    </message>
    <message>
        <location filename="../src/core/ui/mainwindow.cpp" line="541"/>
        <source>Save As...</source>
        <translation>Guardar como...</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/core/regionselect.cpp" line="175"/>
        <source>Click and drag to draw a rectangle,
right click to fit to edges,
double click or press Enter
to take a screenshot.</source>
        <translation>Clique e arraste para criar um retângulo,
botão direito do rato para ajustar às margens,
duplo clique ou Enter para obter a captura.</translation>
    </message>
    <message>
        <location filename="../src/core/regionselect.cpp" line="207"/>
        <source>%1 x %2 pixels </source>
        <translation>%1 x %2 pixeis </translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="35"/>
        <source>External edit</source>
        <translation>Edição externa</translation>
    </message>
    <message>
        <location filename="../src/modules/extedit/moduleextedit.cpp" line="46"/>
        <source>Edit in...</source>
        <translation>Editar com...</translation>
    </message>
</context>
<context>
    <name>aboutWidget</name>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="118"/>
        <source>About Qt</source>
        <translation>Acerca de Qt</translation>
    </message>
    <message>
        <location filename="../src/core/ui/aboutwidget.ui" line="144"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
</context>
<context>
    <name>configwidget</name>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="26"/>
        <location filename="../src/core/ui/configwidget.ui" line="568"/>
        <source>Options</source>
        <translation>Opções</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="77"/>
        <source>Main</source>
        <translation>Principal</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="82"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="87"/>
        <source>System tray</source>
        <translation>Bandeja</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="92"/>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="116"/>
        <source>Default save directory</source>
        <translation>Diretório para guardar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="122"/>
        <source>Path to default selection dir for saving</source>
        <translation>Caminho do diretório a utilizar para guardar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="135"/>
        <source>Browse filesystem</source>
        <translation>Explorar sistema de ficheiros</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="138"/>
        <source>Browse</source>
        <translation>Explorar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="148"/>
        <source>Default file</source>
        <translation>Ficheiro padrão</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="161"/>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="168"/>
        <source>Default filename</source>
        <translation>Nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="179"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="192"/>
        <source>Default saving image format</source>
        <translation>Formato utilizado para guardar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="211"/>
        <source>Copy file name to the clipboard when saving</source>
        <translation>Copia nome do ficheiro para a área de transferência</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="225"/>
        <source>Do not copy</source>
        <translation>Não copiar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="230"/>
        <source>Copy file name only</source>
        <translation>Copiar apenas o nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="235"/>
        <source>Copy full file path</source>
        <translation>Copiar o caminho</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="245"/>
        <source>Image quality</source>
        <translation>Qualidade da imagem</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="251"/>
        <source>Image quality (1 - small file, 100 - high quality)</source>
        <translation>Qualidade da imagem (1 - menor, 100 - maior)</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="316"/>
        <source>Inserting current date time into saved filename</source>
        <translation>Inserir data e hora atual no nome do ficheiro guardado</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="319"/>
        <source>Insert current date and time in file name</source>
        <translation>Inserir data e hora atual no nome do ficheiro</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="328"/>
        <source>Template: </source>
        <translation>Modelo: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="353"/>
        <source>Example: </source>
        <translation>Exemplo: </translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="363"/>
        <source>Automatically saving screenshots in grabbing process</source>
        <translation>Guardar captura automaticamente no processo de obtenção</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="366"/>
        <source>Autosave screenshot</source>
        <translation>Guardar captura automaticamente</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="378"/>
        <source>Save first screenshot</source>
        <translation>Guardar primeira captura</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="387"/>
        <source>Allow run multiplies copy of ScreenGrab</source>
        <translation>Permitir várias instâncias do ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="390"/>
        <source>Allow multiple instances of ScreenGrab</source>
        <translation>Permitir várias instâncias do ScreenGrab</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="397"/>
        <source>Open in external viewer on double click</source>
        <translation>Duplo clique para abrir a captura no visualizador de imagens externo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="400"/>
        <source>Enable external viewer</source>
        <translation>Ativar visualizador externo</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="407"/>
        <source>If this is unchecked, the selected area
might become larger to fit to outer edges</source>
        <translation>Se desativar a opção, a área selecionada
pode ficar maior para se ajustar às margens</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="411"/>
        <source>Fit to edges inside selected area by right clicking</source>
        <translation>Ajuste as arestas da área selecionada clicando com o botão direito</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="418"/>
        <source>Notify on saving and copying</source>
        <translation>Notificar ao guardar e copiar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="427"/>
        <source>Duration:</source>
        <translation>Duração:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="494"/>
        <source>Show ScreenGrab in the system tray</source>
        <translation>Mostrar ScreenGrab na bandeja do sistema</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="434"/>
        <source> sec</source>
        <translation> seg</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="501"/>
        <source>Minimize to tray on click close button</source>
        <translation>Minimizar para a bandeja ao clicar em Fechar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="504"/>
        <source>Minimize to tray when closing</source>
        <translation>Minimizar para a bandeja ao Fechar</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="543"/>
        <source>Action</source>
        <translation>Ação</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="548"/>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="553"/>
        <source>New screen</source>
        <translation>Novo ecrã</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="558"/>
        <source>Save screen</source>
        <translation>Guardar ecrã</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="563"/>
        <source>Copy screen</source>
        <translation>Copiar ecrã</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="573"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="578"/>
        <source>Quit</source>
        <translation>Sair</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="588"/>
        <source>Selected shortcut:</source>
        <translation>Atalho selecionado:</translation>
    </message>
    <message>
        <location filename="../src/core/ui/configwidget.ui" line="595"/>
        <source>Not defined</source>
        <translation>Não definido</translation>
    </message>
</context>
</TS>
